==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/ShapefileRecordDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ShapefileRecordDescription } from "./ShapefileRecordDescription";
/**
 * @hidden
 */
var ShapefileRecordDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ShapefileRecordDescriptionMetadata, _super);
    function ShapefileRecordDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ShapefileRecordDescriptionMetadata.b = function (a) {
        if (ShapefileRecordDescriptionMetadata.a == null) {
            ShapefileRecordDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ShapefileRecordDescriptionMetadata.c(ShapefileRecordDescriptionMetadata.a);
        }
        if (a.g(ShapefileRecordDescriptionMetadata.a)) {
            return;
        }
        a.s(ShapefileRecordDescriptionMetadata.a);
    };
    ShapefileRecordDescriptionMetadata.c = function (a) {
        a.item("FieldValuesRef", "(w:FieldValues,wf:FieldValues)DataRef");
        a.item("Bounds", "Rect");
    };
    ShapefileRecordDescriptionMetadata.d = function (a) {
        ShapefileRecordDescriptionMetadata.b(a);
        a.u("ShapefileRecord", function () { return new ShapefileRecordDescription(); });
        a.t("ShapefileRecord", ShapefileRecordDescriptionMetadata.a);
    };
    ShapefileRecordDescriptionMetadata.$t = markType(ShapefileRecordDescriptionMetadata, 'ShapefileRecordDescriptionMetadata');
    ShapefileRecordDescriptionMetadata.a = null;
    return ShapefileRecordDescriptionMetadata;
}(Base));
export { ShapefileRecordDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/ShapefileRecordDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ShapefileRecordDescription } from "./ShapefileRecordDescription";
/**
 * @hidden
 */
var ShapefileRecordDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ShapefileRecordDescriptionMetadata, _super);
    function ShapefileRecordDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ShapefileRecordDescriptionMetadata.b = function (a) {
        if (ShapefileRecordDescriptionMetadata.a == null) {
            ShapefileRecordDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ShapefileRecordDescriptionMetadata.c(ShapefileRecordDescriptionMetadata.a);
        }
        if (a.j(ShapefileRecordDescriptionMetadata.a)) {
            return;
        }
        a.y(ShapefileRecordDescriptionMetadata.a);
    };
    ShapefileRecordDescriptionMetadata.c = function (a) {
        a.item("FieldValuesRef", "(w:FieldValues,wf:FieldValues)DataRef");
        a.item("Bounds", "Rect");
    };
    ShapefileRecordDescriptionMetadata.d = function (a) {
        ShapefileRecordDescriptionMetadata.b(a);
        a.aa("ShapefileRecord", function () { return new ShapefileRecordDescription(); });
        a.z("ShapefileRecord", ShapefileRecordDescriptionMetadata.a);
    };
    ShapefileRecordDescriptionMetadata.$t = markType(ShapefileRecordDescriptionMetadata, 'ShapefileRecordDescriptionMetadata');
    ShapefileRecordDescriptionMetadata.a = null;
    return ShapefileRecordDescriptionMetadata;
}(Base));
export { ShapefileRecordDescriptionMetadata };
